# SWAN Gallery MkDocs plugin

Plugin to automatically generate a [SWAN](https://cern.ch/swan) gallery using [MkDocs](https://www.mkdocs.org/).

## How to use

Install the package:
```
pip install mkdocs-swangallery
```

And add it to `mkdocs.yml`:
```yml
plugins:
  - swangallery
```